==> gail-0.3.tar.bz2: gail-0.3/gail/gailprogressbar.h <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GAIL_PROGRESS_BAR_H__
#define __GAIL_PROGRESS_BAR_H__

#include <gtk/gtkaccessible.h>
#include <gail/gailwidget.h>


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GAIL_TYPE_PROGRESS_BAR                      (gail_progress_bar_get_type ())
#define GAIL_PROGRESS_BAR(obj)                      (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAIL_TYPE_PROGRESS_BAR, GailProgressBar))
#define GAIL_PROGRESS_BAR_CLASS(klass)			(G_TYPE_CHECK_CLASS_CAST ((klass), GAIL_TYPE_PROGRESS_BAR, GailProgressBarClass))
#define GAIL_IS_PROGRESS_BAR(obj)			(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAIL_TYPE_PROGRESS_BAR))
#define GAIL_IS_PROGRESS_BAR_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE ((klass), GAIL_TYPE_PROGRESS_BAR))
#define GAIL_PROGRESS_BAR_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS ((obj), GAIL_TYPE_PROGRESS_BAR, GailProgressBarClass))

typedef struct _GailProgressBar         GailProgressBar;
typedef struct _GailProgressBarClass	GailProgressBarClass;

struct _GailProgressBar
{
  GailWidget parent;

  AtkObject *adjustment;
};

GType gail_progress_bar_get_type (void);

struct _GailProgressBarClass
{
  GailWidgetClass parent_class;
};

GtkAccessible *gail_progress_bar_new(GtkWidget *widget);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GAIL_PROGRESS_BAR_H__ */

==> gail-0.17.tar.bz2: gail-0.17/gail/gailprogressbar.h <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GAIL_PROGRESS_BAR_H__
#define __GAIL_PROGRESS_BAR_H__

#include <gtk/gtkaccessible.h>
#include <gail/gailwidget.h>


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GAIL_TYPE_PROGRESS_BAR                      (gail_progress_bar_get_type ())
#define GAIL_PROGRESS_BAR(obj)                      (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAIL_TYPE_PROGRESS_BAR, GailProgressBar))
#define GAIL_PROGRESS_BAR_CLASS(klass)			(G_TYPE_CHECK_CLASS_CAST ((klass), GAIL_TYPE_PROGRESS_BAR, GailProgressBarClass))
#define GAIL_IS_PROGRESS_BAR(obj)			(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAIL_TYPE_PROGRESS_BAR))
#define GAIL_IS_PROGRESS_BAR_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE ((klass), GAIL_TYPE_PROGRESS_BAR))
#define GAIL_PROGRESS_BAR_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS ((obj), GAIL_TYPE_PROGRESS_BAR, GailProgressBarClass))

typedef struct _GailProgressBar         GailProgressBar;
typedef struct _GailProgressBarClass	GailProgressBarClass;

struct _GailProgressBar
{
  GailWidget parent;

  AtkObject *adjustment;
};

GType gail_progress_bar_get_type (void);

struct _GailProgressBarClass
{
  GailWidgetClass parent_class;
};

AtkObject* gail_progress_bar_new (GtkWidget *widget);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GAIL_PROGRESS_BAR_H__ */
